@@ -1,8 +1,9 @@
-from typing import Any, Dict
+from typing import Any, Dict, Optional
 
 import httpx
 
 from ...client import Client
+from ...models.get_hub_flow_by_id_response_200 import GetHubFlowByIdResponse200
 from ...types import Response
 
 
@@ -24,12 +25,20 @@ def _get_kwargs(
     }
 
 
-def _build_response(*, response: httpx.Response) -> Response[None]:
+def _parse_response(*, response: httpx.Response) -> Optional[GetHubFlowByIdResponse200]:
+    if response.status_code == 200:
+        response_200 = GetHubFlowByIdResponse200.from_dict(response.json())
+
+        return response_200
+    return None
+
+
+def _build_response(*, response: httpx.Response) -> Response[GetHubFlowByIdResponse200]:
     return Response(
         status_code=response.status_code,
         content=response.content,
         headers=response.headers,
-        parsed=None,
+        parsed=_parse_response(response=response),
     )
 
 
@@ -37,7 +46,7 @@ def sync_detailed(
     *,
     client: Client,
     id: int,
-) -> Response[None]:
+) -> Response[GetHubFlowByIdResponse200]:
     kwargs = _get_kwargs(
         client=client,
         id=id,
@@ -50,11 +59,24 @@ def sync_detailed(
     return _build_response(response=response)
 
 
+def sync(
+    *,
+    client: Client,
+    id: int,
+) -> Optional[GetHubFlowByIdResponse200]:
+    """ """
+
+    return sync_detailed(
+        client=client,
+        id=id,
+    ).parsed
+
+
 async def asyncio_detailed(
     *,
     client: Client,
     id: int,
-) -> Response[None]:
+) -> Response[GetHubFlowByIdResponse200]:
     kwargs = _get_kwargs(
         client=client,
         id=id,
@@ -64,3 +86,18 @@ async def asyncio_detailed(
         response = await _client.get(**kwargs)
 
     return _build_response(response=response)
+
+
+async def asyncio(
+    *,
+    client: Client,
+    id: int,
+) -> Optional[GetHubFlowByIdResponse200]:
+    """ """
+
+    return (
+        await asyncio_detailed(
+            client=client,
+            id=id,
+        )
+    ).parsed
