@@ -13,7 +13,7 @@ def _get_kwargs(
     workspace: str,
     id: str,
     running: Union[Unset, bool] = UNSET,
-    log_offset: Union[Unset, float] = UNSET,
+    log_offset: Union[Unset, int] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/w/{workspace}/jobs/getupdate/{id}".format(client.base_url, workspace=workspace, id=id)
 
@@ -58,7 +58,7 @@ def sync_detailed(
     workspace: str,
     id: str,
     running: Union[Unset, bool] = UNSET,
-    log_offset: Union[Unset, float] = UNSET,
+    log_offset: Union[Unset, int] = UNSET,
 ) -> Response[GetJobUpdatesResponse200]:
     kwargs = _get_kwargs(
         client=client,
@@ -81,7 +81,7 @@ def sync(
     workspace: str,
     id: str,
     running: Union[Unset, bool] = UNSET,
-    log_offset: Union[Unset, float] = UNSET,
+    log_offset: Union[Unset, int] = UNSET,
 ) -> Optional[GetJobUpdatesResponse200]:
     """ """
 
@@ -100,7 +100,7 @@ async def asyncio_detailed(
     workspace: str,
     id: str,
     running: Union[Unset, bool] = UNSET,
-    log_offset: Union[Unset, float] = UNSET,
+    log_offset: Union[Unset, int] = UNSET,
 ) -> Response[GetJobUpdatesResponse200]:
     kwargs = _get_kwargs(
         client=client,
@@ -122,7 +122,7 @@ async def asyncio(
     workspace: str,
     id: str,
     running: Union[Unset, bool] = UNSET,
-    log_offset: Union[Unset, float] = UNSET,
+    log_offset: Union[Unset, int] = UNSET,
 ) -> Optional[GetJobUpdatesResponse200]:
     """ """
 
