@@ -15,7 +15,7 @@ def _get_kwargs(
     hash_: str,
     json_body: RunScriptByHashJsonBody,
     scheduled_for: Union[Unset, datetime.datetime] = UNSET,
-    scheduled_in_secs: Union[Unset, float] = UNSET,
+    scheduled_in_secs: Union[Unset, int] = UNSET,
     parent_job: Union[Unset, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/w/{workspace}/jobs/run/h/{hash}".format(client.base_url, workspace=workspace, hash=hash_)
@@ -62,7 +62,7 @@ def sync_detailed(
     hash_: str,
     json_body: RunScriptByHashJsonBody,
     scheduled_for: Union[Unset, datetime.datetime] = UNSET,
-    scheduled_in_secs: Union[Unset, float] = UNSET,
+    scheduled_in_secs: Union[Unset, int] = UNSET,
     parent_job: Union[Unset, str] = UNSET,
 ) -> Response[None]:
     kwargs = _get_kwargs(
@@ -89,7 +89,7 @@ async def asyncio_detailed(
     hash_: str,
     json_body: RunScriptByHashJsonBody,
     scheduled_for: Union[Unset, datetime.datetime] = UNSET,
-    scheduled_in_secs: Union[Unset, float] = UNSET,
+    scheduled_in_secs: Union[Unset, int] = UNSET,
     parent_job: Union[Unset, str] = UNSET,
 ) -> Response[None]:
     kwargs = _get_kwargs(
