@@ -10,7 +10,7 @@ def _get_kwargs(
     *,
     client: Client,
     workspace: str,
-    id: str,
+    id: int,
 ) -> Dict[str, Any]:
     url = "{}/w/{workspace}/oauth/disconnect/{id}".format(client.base_url, workspace=workspace, id=id)
 
@@ -38,7 +38,7 @@ def sync_detailed(
     *,
     client: Client,
     workspace: str,
-    id: str,
+    id: int,
 ) -> Response[None]:
     kwargs = _get_kwargs(
         client=client,
@@ -57,7 +57,7 @@ async def asyncio_detailed(
     *,
     client: Client,
     workspace: str,
-    id: str,
+    id: int,
 ) -> Response[None]:
     kwargs = _get_kwargs(
         client=client,
