@@ -23,7 +23,7 @@ def _get_kwargs(
     }
 
 
-def _build_response(*, response: httpx.Response) -> Response[Any]:
+def _build_response(*, response: httpx.Response) -> Response[None]:
     return Response(
         status_code=response.status_code,
         content=response.content,
@@ -35,19 +35,12 @@ def _build_response(*, response: httpx.Response) -> Response[Any]:
 def sync_detailed(
     *,
     client: Client,
-) -> Response[Any]:
-    """logout
-
-    Returns:
-        Response[Any]
-    """
-
+) -> Response[None]:
     kwargs = _get_kwargs(
         client=client,
     )
 
     response = httpx.post(
-        verify=client.verify_ssl,
         **kwargs,
     )
 
@@ -57,18 +50,12 @@ def sync_detailed(
 async def asyncio_detailed(
     *,
     client: Client,
-) -> Response[Any]:
-    """logout
-
-    Returns:
-        Response[Any]
-    """
-
+) -> Response[None]:
     kwargs = _get_kwargs(
         client=client,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
+    async with httpx.AsyncClient() as _client:
         response = await _client.post(**kwargs)
 
     return _build_response(response=response)
