@@ -1,9 +1,11 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
 from ..models.completed_job_flow_status_failure_module import CompletedJobFlowStatusFailureModule
 from ..models.completed_job_flow_status_modules_item import CompletedJobFlowStatusModulesItem
+from ..models.completed_job_flow_status_retry import CompletedJobFlowStatusRetry
+from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="CompletedJobFlowStatus")
 
@@ -15,6 +17,7 @@ class CompletedJobFlowStatus:
     step: int
     modules: List[CompletedJobFlowStatusModulesItem]
     failure_module: CompletedJobFlowStatusFailureModule
+    retry: Union[Unset, CompletedJobFlowStatusRetry] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -27,6 +30,10 @@ class CompletedJobFlowStatus:
 
         failure_module = self.failure_module.to_dict()
 
+        retry: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry, Unset):
+            retry = self.retry.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -36,6 +43,8 @@ class CompletedJobFlowStatus:
                 "failure_module": failure_module,
             }
         )
+        if retry is not UNSET:
+            field_dict["retry"] = retry
 
         return field_dict
 
@@ -53,10 +62,16 @@ class CompletedJobFlowStatus:
 
         failure_module = CompletedJobFlowStatusFailureModule.from_dict(d.pop("failure_module"))
 
+        retry: Union[Unset, CompletedJobFlowStatusRetry] = UNSET
+        _retry = d.pop("retry", UNSET)
+        if not isinstance(_retry, Unset):
+            retry = CompletedJobFlowStatusRetry.from_dict(_retry)
+
         completed_job_flow_status = cls(
             step=step,
             modules=modules,
             failure_module=failure_module,
+            retry=retry,
         )
 
         completed_job_flow_status.additional_properties = d
