@@ -7,6 +7,8 @@ class DeleteCompletedJobResponse200JobKind(str, Enum):
     DEPENDENCIES = "dependencies"
     FLOW = "flow"
     FLOWPREVIEW = "flowpreview"
+    SCRIPT_HUB = "script_hub"
+    IDENTITY = "identity"
 
     def __str__(self) -> str:
         return str(self.value)
