@@ -19,6 +19,7 @@ class DeleteCompletedJobResponse200RawFlow:
 
     modules: List[DeleteCompletedJobResponse200RawFlowModulesItem]
     failure_module: Union[Unset, DeleteCompletedJobResponse200RawFlowFailureModule] = UNSET
+    same_worker: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -32,6 +33,8 @@ class DeleteCompletedJobResponse200RawFlow:
         if not isinstance(self.failure_module, Unset):
             failure_module = self.failure_module.to_dict()
 
+        same_worker = self.same_worker
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -41,6 +44,8 @@ class DeleteCompletedJobResponse200RawFlow:
         )
         if failure_module is not UNSET:
             field_dict["failure_module"] = failure_module
+        if same_worker is not UNSET:
+            field_dict["same_worker"] = same_worker
 
         return field_dict
 
@@ -59,9 +64,12 @@ class DeleteCompletedJobResponse200RawFlow:
         if not isinstance(_failure_module, Unset):
             failure_module = DeleteCompletedJobResponse200RawFlowFailureModule.from_dict(_failure_module)
 
+        same_worker = d.pop("same_worker", UNSET)
+
         delete_completed_job_response_200_raw_flow = cls(
             modules=modules,
             failure_module=failure_module,
+            same_worker=same_worker,
         )
 
         delete_completed_job_response_200_raw_flow.additional_properties = d
