@@ -1,9 +1,11 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
 from ..models.flow_status_failure_module import FlowStatusFailureModule
 from ..models.flow_status_modules_item import FlowStatusModulesItem
+from ..models.flow_status_retry import FlowStatusRetry
+from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="FlowStatus")
 
@@ -15,6 +17,7 @@ class FlowStatus:
     step: int
     modules: List[FlowStatusModulesItem]
     failure_module: FlowStatusFailureModule
+    retry: Union[Unset, FlowStatusRetry] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -27,6 +30,10 @@ class FlowStatus:
 
         failure_module = self.failure_module.to_dict()
 
+        retry: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry, Unset):
+            retry = self.retry.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -36,6 +43,8 @@ class FlowStatus:
                 "failure_module": failure_module,
             }
         )
+        if retry is not UNSET:
+            field_dict["retry"] = retry
 
         return field_dict
 
@@ -53,10 +62,16 @@ class FlowStatus:
 
         failure_module = FlowStatusFailureModule.from_dict(d.pop("failure_module"))
 
+        retry: Union[Unset, FlowStatusRetry] = UNSET
+        _retry = d.pop("retry", UNSET)
+        if not isinstance(_retry, Unset):
+            retry = FlowStatusRetry.from_dict(_retry)
+
         flow_status = cls(
             step=step,
             modules=modules,
             failure_module=failure_module,
+            retry=retry,
         )
 
         flow_status.additional_properties = d
