@@ -23,12 +23,13 @@ class GetCompletedJobResponse200:
     created_by: str
     created_at: datetime.datetime
     started_at: datetime.datetime
-    duration: int
+    duration_ms: int
     success: bool
     canceled: bool
     job_kind: GetCompletedJobResponse200JobKind
     permissioned_as: str
     is_flow_step: bool
+    is_skipped: bool
     workspace_id: Union[Unset, str] = UNSET
     parent_job: Union[Unset, str] = UNSET
     script_path: Union[Unset, str] = UNSET
@@ -53,13 +54,14 @@ class GetCompletedJobResponse200:
 
         started_at = self.started_at.isoformat()
 
-        duration = self.duration
+        duration_ms = self.duration_ms
         success = self.success
         canceled = self.canceled
         job_kind = self.job_kind.value
 
         permissioned_as = self.permissioned_as
         is_flow_step = self.is_flow_step
+        is_skipped = self.is_skipped
         workspace_id = self.workspace_id
         parent_job = self.parent_job
         script_path = self.script_path
@@ -98,12 +100,13 @@ class GetCompletedJobResponse200:
                 "created_by": created_by,
                 "created_at": created_at,
                 "started_at": started_at,
-                "duration": duration,
+                "duration_ms": duration_ms,
                 "success": success,
                 "canceled": canceled,
                 "job_kind": job_kind,
                 "permissioned_as": permissioned_as,
                 "is_flow_step": is_flow_step,
+                "is_skipped": is_skipped,
             }
         )
         if workspace_id is not UNSET:
@@ -150,7 +153,7 @@ class GetCompletedJobResponse200:
 
         started_at = isoparse(d.pop("started_at"))
 
-        duration = d.pop("duration")
+        duration_ms = d.pop("duration_ms")
 
         success = d.pop("success")
 
@@ -162,6 +165,8 @@ class GetCompletedJobResponse200:
 
         is_flow_step = d.pop("is_flow_step")
 
+        is_skipped = d.pop("is_skipped")
+
         workspace_id = d.pop("workspace_id", UNSET)
 
         parent_job = d.pop("parent_job", UNSET)
@@ -212,12 +217,13 @@ class GetCompletedJobResponse200:
             created_by=created_by,
             created_at=created_at,
             started_at=started_at,
-            duration=duration,
+            duration_ms=duration_ms,
             success=success,
             canceled=canceled,
             job_kind=job_kind,
             permissioned_as=permissioned_as,
             is_flow_step=is_flow_step,
+            is_skipped=is_skipped,
             workspace_id=workspace_id,
             parent_job=parent_job,
             script_path=script_path,
