@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
@@ -8,6 +8,8 @@ from ..models.get_completed_job_response_200_flow_status_failure_module import (
 from ..models.get_completed_job_response_200_flow_status_modules_item import (
     GetCompletedJobResponse200FlowStatusModulesItem,
 )
+from ..models.get_completed_job_response_200_flow_status_retry import GetCompletedJobResponse200FlowStatusRetry
+from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="GetCompletedJobResponse200FlowStatus")
 
@@ -19,6 +21,7 @@ class GetCompletedJobResponse200FlowStatus:
     step: int
     modules: List[GetCompletedJobResponse200FlowStatusModulesItem]
     failure_module: GetCompletedJobResponse200FlowStatusFailureModule
+    retry: Union[Unset, GetCompletedJobResponse200FlowStatusRetry] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -31,6 +34,10 @@ class GetCompletedJobResponse200FlowStatus:
 
         failure_module = self.failure_module.to_dict()
 
+        retry: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry, Unset):
+            retry = self.retry.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -40,6 +47,8 @@ class GetCompletedJobResponse200FlowStatus:
                 "failure_module": failure_module,
             }
         )
+        if retry is not UNSET:
+            field_dict["retry"] = retry
 
         return field_dict
 
@@ -57,10 +66,16 @@ class GetCompletedJobResponse200FlowStatus:
 
         failure_module = GetCompletedJobResponse200FlowStatusFailureModule.from_dict(d.pop("failure_module"))
 
+        retry: Union[Unset, GetCompletedJobResponse200FlowStatusRetry] = UNSET
+        _retry = d.pop("retry", UNSET)
+        if not isinstance(_retry, Unset):
+            retry = GetCompletedJobResponse200FlowStatusRetry.from_dict(_retry)
+
         get_completed_job_response_200_flow_status = cls(
             step=step,
             modules=modules,
             failure_module=failure_module,
+            retry=retry,
         )
 
         get_completed_job_response_200_flow_status.additional_properties = d
