@@ -17,6 +17,7 @@ class GetCompletedJobResponse200RawFlow:
 
     modules: List[GetCompletedJobResponse200RawFlowModulesItem]
     failure_module: Union[Unset, GetCompletedJobResponse200RawFlowFailureModule] = UNSET
+    same_worker: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -30,6 +31,8 @@ class GetCompletedJobResponse200RawFlow:
         if not isinstance(self.failure_module, Unset):
             failure_module = self.failure_module.to_dict()
 
+        same_worker = self.same_worker
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -39,6 +42,8 @@ class GetCompletedJobResponse200RawFlow:
         )
         if failure_module is not UNSET:
             field_dict["failure_module"] = failure_module
+        if same_worker is not UNSET:
+            field_dict["same_worker"] = same_worker
 
         return field_dict
 
@@ -57,9 +62,12 @@ class GetCompletedJobResponse200RawFlow:
         if not isinstance(_failure_module, Unset):
             failure_module = GetCompletedJobResponse200RawFlowFailureModule.from_dict(_failure_module)
 
+        same_worker = d.pop("same_worker", UNSET)
+
         get_completed_job_response_200_raw_flow = cls(
             modules=modules,
             failure_module=failure_module,
+            same_worker=same_worker,
         )
 
         get_completed_job_response_200_raw_flow.additional_properties = d
