@@ -20,10 +20,10 @@ class GetScheduleResponse200:
     edited_at: datetime.datetime
     schedule: str
     offset: int
+    enabled: bool
     script_path: str
     is_flow: bool
     extra_perms: GetScheduleResponse200ExtraPerms
-    enabled: Union[Unset, bool] = UNSET
     args: Union[Unset, GetScheduleResponse200Args] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
@@ -34,11 +34,11 @@ class GetScheduleResponse200:
 
         schedule = self.schedule
         offset = self.offset
+        enabled = self.enabled
         script_path = self.script_path
         is_flow = self.is_flow
         extra_perms = self.extra_perms.to_dict()
 
-        enabled = self.enabled
         args: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.args, Unset):
             args = self.args.to_dict()
@@ -52,13 +52,12 @@ class GetScheduleResponse200:
                 "edited_at": edited_at,
                 "schedule": schedule,
                 "offset_": offset,
+                "enabled": enabled,
                 "script_path": script_path,
                 "is_flow": is_flow,
                 "extra_perms": extra_perms,
             }
         )
-        if enabled is not UNSET:
-            field_dict["enabled"] = enabled
         if args is not UNSET:
             field_dict["args"] = args
 
@@ -77,14 +76,14 @@ class GetScheduleResponse200:
 
         offset = d.pop("offset_")
 
+        enabled = d.pop("enabled")
+
         script_path = d.pop("script_path")
 
         is_flow = d.pop("is_flow")
 
         extra_perms = GetScheduleResponse200ExtraPerms.from_dict(d.pop("extra_perms"))
 
-        enabled = d.pop("enabled", UNSET)
-
         args: Union[Unset, GetScheduleResponse200Args] = UNSET
         _args = d.pop("args", UNSET)
         if not isinstance(_args, Unset):
@@ -96,10 +95,10 @@ class GetScheduleResponse200:
             edited_at=edited_at,
             schedule=schedule,
             offset=offset,
+            enabled=enabled,
             script_path=script_path,
             is_flow=is_flow,
             extra_perms=extra_perms,
-            enabled=enabled,
             args=args,
         )
 
