@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
@@ -8,6 +8,10 @@ from ..models.list_completed_jobs_response_200_item_flow_status_failure_module i
 from ..models.list_completed_jobs_response_200_item_flow_status_modules_item import (
     ListCompletedJobsResponse200ItemFlowStatusModulesItem,
 )
+from ..models.list_completed_jobs_response_200_item_flow_status_retry import (
+    ListCompletedJobsResponse200ItemFlowStatusRetry,
+)
+from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="ListCompletedJobsResponse200ItemFlowStatus")
 
@@ -19,6 +23,7 @@ class ListCompletedJobsResponse200ItemFlowStatus:
     step: int
     modules: List[ListCompletedJobsResponse200ItemFlowStatusModulesItem]
     failure_module: ListCompletedJobsResponse200ItemFlowStatusFailureModule
+    retry: Union[Unset, ListCompletedJobsResponse200ItemFlowStatusRetry] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -31,6 +36,10 @@ class ListCompletedJobsResponse200ItemFlowStatus:
 
         failure_module = self.failure_module.to_dict()
 
+        retry: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry, Unset):
+            retry = self.retry.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -40,6 +49,8 @@ class ListCompletedJobsResponse200ItemFlowStatus:
                 "failure_module": failure_module,
             }
         )
+        if retry is not UNSET:
+            field_dict["retry"] = retry
 
         return field_dict
 
@@ -57,10 +68,16 @@ class ListCompletedJobsResponse200ItemFlowStatus:
 
         failure_module = ListCompletedJobsResponse200ItemFlowStatusFailureModule.from_dict(d.pop("failure_module"))
 
+        retry: Union[Unset, ListCompletedJobsResponse200ItemFlowStatusRetry] = UNSET
+        _retry = d.pop("retry", UNSET)
+        if not isinstance(_retry, Unset):
+            retry = ListCompletedJobsResponse200ItemFlowStatusRetry.from_dict(_retry)
+
         list_completed_jobs_response_200_item_flow_status = cls(
             step=step,
             modules=modules,
             failure_module=failure_module,
+            retry=retry,
         )
 
         list_completed_jobs_response_200_item_flow_status.additional_properties = d
