@@ -19,6 +19,7 @@ class ListCompletedJobsResponse200ItemRawFlow:
 
     modules: List[ListCompletedJobsResponse200ItemRawFlowModulesItem]
     failure_module: Union[Unset, ListCompletedJobsResponse200ItemRawFlowFailureModule] = UNSET
+    same_worker: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -32,6 +33,8 @@ class ListCompletedJobsResponse200ItemRawFlow:
         if not isinstance(self.failure_module, Unset):
             failure_module = self.failure_module.to_dict()
 
+        same_worker = self.same_worker
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -41,6 +44,8 @@ class ListCompletedJobsResponse200ItemRawFlow:
         )
         if failure_module is not UNSET:
             field_dict["failure_module"] = failure_module
+        if same_worker is not UNSET:
+            field_dict["same_worker"] = same_worker
 
         return field_dict
 
@@ -59,9 +64,12 @@ class ListCompletedJobsResponse200ItemRawFlow:
         if not isinstance(_failure_module, Unset):
             failure_module = ListCompletedJobsResponse200ItemRawFlowFailureModule.from_dict(_failure_module)
 
+        same_worker = d.pop("same_worker", UNSET)
+
         list_completed_jobs_response_200_item_raw_flow = cls(
             modules=modules,
             failure_module=failure_module,
+            same_worker=same_worker,
         )
 
         list_completed_jobs_response_200_item_raw_flow.additional_properties = d
