@@ -16,66 +16,71 @@ T = TypeVar("T", bound="ListFlowsResponse200Item")
 class ListFlowsResponse200Item:
     """ """
 
-    path: str
     summary: str
     value: ListFlowsResponse200ItemValue
+    path: str
     edited_by: str
     edited_at: datetime.datetime
     archived: bool
     extra_perms: ListFlowsResponse200ItemExtraPerms
-    workspace_id: Union[Unset, str] = UNSET
     description: Union[Unset, str] = UNSET
     schema: Union[Unset, ListFlowsResponse200ItemSchema] = UNSET
+    workspace_id: Union[Unset, str] = UNSET
+    additional_properties: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
-        path = self.path
         summary = self.summary
         value = self.value.to_dict()
 
+        path = self.path
         edited_by = self.edited_by
         edited_at = self.edited_at.isoformat()
 
         archived = self.archived
         extra_perms = self.extra_perms.to_dict()
 
-        workspace_id = self.workspace_id
         description = self.description
         schema: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.schema, Unset):
             schema = self.schema.to_dict()
 
+        workspace_id = self.workspace_id
+        additional_properties = self.additional_properties
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
             {
-                "path": path,
                 "summary": summary,
                 "value": value,
+                "path": path,
                 "edited_by": edited_by,
                 "edited_at": edited_at,
                 "archived": archived,
                 "extra_perms": extra_perms,
             }
         )
-        if workspace_id is not UNSET:
-            field_dict["workspace_id"] = workspace_id
         if description is not UNSET:
             field_dict["description"] = description
         if schema is not UNSET:
             field_dict["schema"] = schema
+        if workspace_id is not UNSET:
+            field_dict["workspace_id"] = workspace_id
+        if additional_properties is not UNSET:
+            field_dict["additionalProperties"] = additional_properties
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        path = d.pop("path")
-
         summary = d.pop("summary")
 
         value = ListFlowsResponse200ItemValue.from_dict(d.pop("value"))
 
+        path = d.pop("path")
+
         edited_by = d.pop("edited_by")
 
         edited_at = isoparse(d.pop("edited_at"))
@@ -84,8 +89,6 @@ class ListFlowsResponse200Item:
 
         extra_perms = ListFlowsResponse200ItemExtraPerms.from_dict(d.pop("extra_perms"))
 
-        workspace_id = d.pop("workspace_id", UNSET)
-
         description = d.pop("description", UNSET)
 
         schema: Union[Unset, ListFlowsResponse200ItemSchema] = UNSET
@@ -93,17 +96,22 @@ class ListFlowsResponse200Item:
         if not isinstance(_schema, Unset):
             schema = ListFlowsResponse200ItemSchema.from_dict(_schema)
 
+        workspace_id = d.pop("workspace_id", UNSET)
+
+        additional_properties = d.pop("additionalProperties", UNSET)
+
         list_flows_response_200_item = cls(
-            path=path,
             summary=summary,
             value=value,
+            path=path,
             edited_by=edited_by,
             edited_at=edited_at,
             archived=archived,
             extra_perms=extra_perms,
-            workspace_id=workspace_id,
             description=description,
             schema=schema,
+            workspace_id=workspace_id,
+            additional_properties=additional_properties,
         )
 
         list_flows_response_200_item.additional_properties = d
