@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
@@ -6,6 +6,8 @@ from ..models.list_queue_response_200_item_flow_status_failure_module import (
     ListQueueResponse200ItemFlowStatusFailureModule,
 )
 from ..models.list_queue_response_200_item_flow_status_modules_item import ListQueueResponse200ItemFlowStatusModulesItem
+from ..models.list_queue_response_200_item_flow_status_retry import ListQueueResponse200ItemFlowStatusRetry
+from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="ListQueueResponse200ItemFlowStatus")
 
@@ -17,6 +19,7 @@ class ListQueueResponse200ItemFlowStatus:
     step: int
     modules: List[ListQueueResponse200ItemFlowStatusModulesItem]
     failure_module: ListQueueResponse200ItemFlowStatusFailureModule
+    retry: Union[Unset, ListQueueResponse200ItemFlowStatusRetry] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -29,6 +32,10 @@ class ListQueueResponse200ItemFlowStatus:
 
         failure_module = self.failure_module.to_dict()
 
+        retry: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry, Unset):
+            retry = self.retry.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -38,6 +45,8 @@ class ListQueueResponse200ItemFlowStatus:
                 "failure_module": failure_module,
             }
         )
+        if retry is not UNSET:
+            field_dict["retry"] = retry
 
         return field_dict
 
@@ -55,10 +64,16 @@ class ListQueueResponse200ItemFlowStatus:
 
         failure_module = ListQueueResponse200ItemFlowStatusFailureModule.from_dict(d.pop("failure_module"))
 
+        retry: Union[Unset, ListQueueResponse200ItemFlowStatusRetry] = UNSET
+        _retry = d.pop("retry", UNSET)
+        if not isinstance(_retry, Unset):
+            retry = ListQueueResponse200ItemFlowStatusRetry.from_dict(_retry)
+
         list_queue_response_200_item_flow_status = cls(
             step=step,
             modules=modules,
             failure_module=failure_module,
+            retry=retry,
         )
 
         list_queue_response_200_item_flow_status.additional_properties = d
