@@ -4,6 +4,7 @@ from typing import Any, Dict, List, Type, TypeVar, Union, cast
 import attr
 from dateutil.parser import isoparse
 
+from ..models.list_users_response_200_item_usage import ListUsersResponse200ItemUsage
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="ListUsersResponse200Item")
@@ -21,6 +22,7 @@ class ListUsersResponse200Item:
     operator: bool
     disabled: bool
     groups: Union[Unset, List[str]] = UNSET
+    usage: Union[Unset, ListUsersResponse200ItemUsage] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -36,6 +38,10 @@ class ListUsersResponse200Item:
         if not isinstance(self.groups, Unset):
             groups = self.groups
 
+        usage: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.usage, Unset):
+            usage = self.usage.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -51,6 +57,8 @@ class ListUsersResponse200Item:
         )
         if groups is not UNSET:
             field_dict["groups"] = groups
+        if usage is not UNSET:
+            field_dict["usage"] = usage
 
         return field_dict
 
@@ -73,6 +81,11 @@ class ListUsersResponse200Item:
 
         groups = cast(List[str], d.pop("groups", UNSET))
 
+        usage: Union[Unset, ListUsersResponse200ItemUsage] = UNSET
+        _usage = d.pop("usage", UNSET)
+        if not isinstance(_usage, Unset):
+            usage = ListUsersResponse200ItemUsage.from_dict(_usage)
+
         list_users_response_200_item = cls(
             email=email,
             username=username,
@@ -82,6 +95,7 @@ class ListUsersResponse200Item:
             operator=operator,
             disabled=disabled,
             groups=groups,
+            usage=usage,
         )
 
         list_users_response_200_item.additional_properties = d
