@@ -5,6 +5,8 @@ import attr
 from ..models.main_arg_signature_args_item_typ_type_0 import MainArgSignatureArgsItemTypType0
 from ..models.main_arg_signature_args_item_typ_type_1 import MainArgSignatureArgsItemTypType1
 from ..models.main_arg_signature_args_item_typ_type_2 import MainArgSignatureArgsItemTypType2
+from ..models.main_arg_signature_args_item_typ_type_3 import MainArgSignatureArgsItemTypType3
+from ..models.main_arg_signature_args_item_typ_type_4 import MainArgSignatureArgsItemTypType4
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="MainArgSignatureArgsItem")
@@ -15,7 +17,13 @@ class MainArgSignatureArgsItem:
     """ """
 
     name: str
-    typ: Union[MainArgSignatureArgsItemTypType0, MainArgSignatureArgsItemTypType1, MainArgSignatureArgsItemTypType2]
+    typ: Union[
+        MainArgSignatureArgsItemTypType0,
+        MainArgSignatureArgsItemTypType1,
+        MainArgSignatureArgsItemTypType2,
+        MainArgSignatureArgsItemTypType3,
+        MainArgSignatureArgsItemTypType4,
+    ]
     has_default: Union[Unset, bool] = UNSET
     default: Union[Unset, None] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
@@ -28,6 +36,12 @@ class MainArgSignatureArgsItem:
         elif isinstance(self.typ, MainArgSignatureArgsItemTypType1):
             typ = self.typ.to_dict()
 
+        elif isinstance(self.typ, MainArgSignatureArgsItemTypType2):
+            typ = self.typ.to_dict()
+
+        elif isinstance(self.typ, MainArgSignatureArgsItemTypType3):
+            typ = self.typ.to_dict()
+
         else:
             typ = self.typ.to_dict()
 
@@ -57,7 +71,11 @@ class MainArgSignatureArgsItem:
         def _parse_typ(
             data: object,
         ) -> Union[
-            MainArgSignatureArgsItemTypType0, MainArgSignatureArgsItemTypType1, MainArgSignatureArgsItemTypType2
+            MainArgSignatureArgsItemTypType0,
+            MainArgSignatureArgsItemTypType1,
+            MainArgSignatureArgsItemTypType2,
+            MainArgSignatureArgsItemTypType3,
+            MainArgSignatureArgsItemTypType4,
         ]:
             try:
                 typ_type_0: MainArgSignatureArgsItemTypType0
@@ -77,12 +95,30 @@ class MainArgSignatureArgsItem:
                 return typ_type_1
             except:  # noqa: E722
                 pass
+            try:
+                typ_type_2: MainArgSignatureArgsItemTypType2
+                if not isinstance(data, dict):
+                    raise TypeError()
+                typ_type_2 = MainArgSignatureArgsItemTypType2.from_dict(data)
+
+                return typ_type_2
+            except:  # noqa: E722
+                pass
+            try:
+                typ_type_3: MainArgSignatureArgsItemTypType3
+                if not isinstance(data, dict):
+                    raise TypeError()
+                typ_type_3 = MainArgSignatureArgsItemTypType3.from_dict(data)
+
+                return typ_type_3
+            except:  # noqa: E722
+                pass
             if not isinstance(data, dict):
                 raise TypeError()
-            typ_type_2: MainArgSignatureArgsItemTypType2
-            typ_type_2 = MainArgSignatureArgsItemTypType2.from_dict(data)
+            typ_type_4: MainArgSignatureArgsItemTypType4
+            typ_type_4 = MainArgSignatureArgsItemTypType4.from_dict(data)
 
-            return typ_type_2
+            return typ_type_4
 
         typ = _parse_typ(d.pop("typ"))
 
