@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Type, TypeVar
+from typing import Any, Dict, List, Optional, Type, TypeVar
 
 import attr
 
@@ -9,7 +9,7 @@ T = TypeVar("T", bound="MainArgSignatureArgsItemTypType1")
 class MainArgSignatureArgsItemTypType1:
     """ """
 
-    resource: str
+    resource: Optional[str]
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
