@@ -15,6 +15,7 @@ class QueuedJobRawFlow:
 
     modules: List[QueuedJobRawFlowModulesItem]
     failure_module: Union[Unset, QueuedJobRawFlowFailureModule] = UNSET
+    same_worker: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -28,6 +29,8 @@ class QueuedJobRawFlow:
         if not isinstance(self.failure_module, Unset):
             failure_module = self.failure_module.to_dict()
 
+        same_worker = self.same_worker
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -37,6 +40,8 @@ class QueuedJobRawFlow:
         )
         if failure_module is not UNSET:
             field_dict["failure_module"] = failure_module
+        if same_worker is not UNSET:
+            field_dict["same_worker"] = same_worker
 
         return field_dict
 
@@ -55,9 +60,12 @@ class QueuedJobRawFlow:
         if not isinstance(_failure_module, Unset):
             failure_module = QueuedJobRawFlowFailureModule.from_dict(_failure_module)
 
+        same_worker = d.pop("same_worker", UNSET)
+
         queued_job_raw_flow = cls(
             modules=modules,
             failure_module=failure_module,
+            same_worker=same_worker,
         )
 
         queued_job_raw_flow.additional_properties = d
