@@ -13,19 +13,19 @@ T = TypeVar("T", bound="UpdateFlowJsonBody")
 class UpdateFlowJsonBody:
     """ """
 
-    path: str
     summary: str
-    description: str
     value: UpdateFlowJsonBodyValue
+    path: str
+    description: Union[Unset, str] = UNSET
     schema: Union[Unset, UpdateFlowJsonBodySchema] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
-        path = self.path
         summary = self.summary
-        description = self.description
         value = self.value.to_dict()
 
+        path = self.path
+        description = self.description
         schema: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.schema, Unset):
             schema = self.schema.to_dict()
@@ -34,12 +34,13 @@ class UpdateFlowJsonBody:
         field_dict.update(self.additional_properties)
         field_dict.update(
             {
-                "path": path,
                 "summary": summary,
-                "description": description,
                 "value": value,
+                "path": path,
             }
         )
+        if description is not UNSET:
+            field_dict["description"] = description
         if schema is not UNSET:
             field_dict["schema"] = schema
 
@@ -48,24 +49,24 @@ class UpdateFlowJsonBody:
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        path = d.pop("path")
-
         summary = d.pop("summary")
 
-        description = d.pop("description")
-
         value = UpdateFlowJsonBodyValue.from_dict(d.pop("value"))
 
+        path = d.pop("path")
+
+        description = d.pop("description", UNSET)
+
         schema: Union[Unset, UpdateFlowJsonBodySchema] = UNSET
         _schema = d.pop("schema", UNSET)
         if not isinstance(_schema, Unset):
             schema = UpdateFlowJsonBodySchema.from_dict(_schema)
 
         update_flow_json_body = cls(
-            path=path,
             summary=summary,
-            description=description,
             value=value,
+            path=path,
+            description=description,
             schema=schema,
         )
 
