@@ -16,7 +16,7 @@ class WorkerPing:
     ping_at: datetime.datetime
     started_at: datetime.datetime
     ip: str
-    jobs_executed: float
+    jobs_executed: int
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
